==> barc-0.0.1.tgz: package/lib/barc.js <==
/*!
 * Barc
 * Copyright (c) 2011 Peter Magnusson <kmpm@birchroad.net>
 * MIT Licensed
 */


var Graphics = require('./graphics-canvas').Graphics;


var Barc = module.exports = function Barc(options){
	if (typeof options == 'undefined') options = {};
	this.font = 'FreeMono';
	if ('font' in options){
		this.font = options.font
	}
	
	this.hri = true;
	if('hri' in options){
		this.hri = options.hri
	}

	this.fontsize=0;
	if('fontsize' in options)
		this.fontsize = parseInt(options.fontsize);

	this.border = 0;
	if ('border' in options){
		var b = options.border
		//auto is the only allowed string
		if (typeof b == 'string' && b=="auto") {
			this.border = function(width, height){
				return Math.round(width / 30);
			}
		}
		else if (typeof b == 'function'){
			//TODO:check signature if possible
			this.border = b;
		}
	}

	this.padding=0;
	if('padding' in options){
		var p = options.padding
		//auto is the only allowed string
		if (typeof p == 'string' && p=="auto") {
			this.padding = function(width, height){
				return this.border*2;
			}
		}
		else if (typeof b == 'function'){
			//TODO:check signature if possible
			this.border = b;
		}
	}
}



/*
angle - in degrees
callback(null, code, buf, bits)
*/
Barc.prototype.code2of5 = function(code, width, height, angle, callback){
	
	width = parseInt(width);
	height = parseInt(height);
	angle = typeof angle !== 'undefined' ? angle:0;
	angle=parseInt(angle);

	var useCallback = typeof callback != "undefined";
	//TODO:validate the values or err

	if(angle>=360)angle = 0;

	var MULTIPLE = 2.5;
	var VALUE_ENCODINGS = {
		'0':"nnWWn",
		'1':"WnnnW",
	    '2':"nWnnW",
	    '3':"WWnnn",
	    '4':"nnWnW",
	    '5':"WnWnn",
	    '6':"nWWnn",
	    '7':"nnnWW",
	    '8':"WnnWn",
	    '9':"nWnWn",
	    ' ':"12470",
	    'START':"NnNn",
	    'STOP':"WnNn",
	};

	var c = makeCode(code);
	code = c[0];
	var bits = c[1];

	g = new Graphics(width, height, this.border, this.padding
		, this.font, this.fontsize);

	//get the width of a narrow bar dynamically 
	//depending on the size of the code
	//and the available width
	var narrow_width = getnarrow(code, g.area.width);
	var wide_width = narrow_width * MULTIPLE;
	
	x=g.area.left;
	for(var bit =0, len = bits.length; bit<len; bit++){
		var chr = bits[bit];
		var chr_l = chr.toLowerCase();
		var x2 =0; //the far x
		var current_width = wide_width;
		if(chr_l == 'n'){
			x2 = x+narrow_width;
			current_width = narrow_width;
		}
		x2 = x+current_width;
		if(chr =='N' || chr == 'W'){
			//if bar and not space
			g.fillFgRect(Math.round(x), 0, current_width, height);
		}
		x = x2;
	}
	

	if(this.hri==true){
		//** and print the hri
		g.fillText(code, width/2, height);
	}

    if(angle>0){
    	g.rotate(angle);
	}
	

	
	var buf = g.toBuffer();
	if(useCallback){
		//called with callback
		callback(null, code, buf, bits);
		return buf;
	}
	else{
		//regular return
		return buf;
	}

	function makeCode(code){
		if((code.length % 2) != 0){
			//the length of an 2of5 code must be even
			code = "0" +code;
	 	}
	 	var strCode = VALUE_ENCODINGS['START'];
	 	var bar = true
	 	var values = [];
	 	for(var i = 0, len=code.length; i<len;i++){
	 		var encoding = VALUE_ENCODINGS[code[i]];
	 		if (bar){
	 			encoding = encoding.toUpperCase();
	 		}
	 		else {
	 			encoding = encoding.toLowerCase();
	 		}
	 		values.push(encoding);
	 		bar = !bar;
	 		if(values.length == 2){
	 			for(var j=0; j<5;j++){
	 				strCode += values[0][j] + values[1][j];
	 			}
	 			values = [];
	 			bar=true;
	 		}
	 	}
	 	strCode += VALUE_ENCODINGS['STOP'];
	 	return [code, strCode];
	}

	function getnarrow(code, width){
	        //returns narrow width in pixels
	        /*
	        L = (C (2N + 3) + 6 + N)X
	        L = length of symbol (not counting quiet zone)
	        C = number of code characters
	        X = X-dimension
	        N = wide-to-narrow MULTIPLE
	        */
	        narrow = code.length * (2.0*MULTIPLE+3.0)+6.0+MULTIPLE
	        return width/narrow
	}
}

==> barc-0.0.2.tgz: package/lib/barc.js <==
/*!
 * Barc
 * Copyright (c) 2011 Peter Magnusson <kmpm@birchroad.net>
 * MIT Licensed
 */


var Graphics = require('./graphics-canvas').Graphics;


var Barc = module.exports = function Barc(options){
	if (typeof options == 'undefined') options = {};
	this.font = 'FreeMono';
	if ('font' in options){
		this.font = options.font
	}
	
	this.hri = true;
	if('hri' in options){
		this.hri = options.hri
	}

	this.fontsize=0;
	if('fontsize' in options)
		this.fontsize = parseInt(options.fontsize);

	this.border = 0;
	if ('border' in options){
		var b = options.border
		//auto is the only allowed string
		if (typeof b == 'string' && b=="auto") {
			this.border = function(width, height){
				return Math.round(height / 30);
			}
		}
		else if (typeof b == 'function'){
			//TODO:check signature if possible
			this.border = b;
		}
	}

	this.padding=0;
	if('padding' in options){
		var p = options.padding
		//auto is the only allowed string
		if (typeof p == 'string' && p=="auto") {
			this.padding = function(width, height){
				return this.border*2;
			}
		}
		else if (typeof b == 'function'){
			//TODO:check signature if possible
			this.border = b;
		}
	}
}

Barc.prototype.code128 = require('./code128').code128;

/*
angle - in degrees
callback(null, code, buf, bits)
*/
Barc.prototype.code2of5 = function(code, width, height, angle, callback){
	
	width = parseInt(width);
	height = parseInt(height);
	angle = typeof angle !== 'undefined' ? angle:0;
	angle=parseInt(angle);

	var useCallback = typeof callback != "undefined";
	//TODO:validate the values or err

	if(angle>=360)angle = 0;

	var MULTIPLE = 2.5;
	var VALUE_ENCODINGS = {
		'0':"nnWWn",
		'1':"WnnnW",
	    '2':"nWnnW",
	    '3':"WWnnn",
	    '4':"nnWnW",
	    '5':"WnWnn",
	    '6':"nWWnn",
	    '7':"nnnWW",
	    '8':"WnnWn",
	    '9':"nWnWn",
	    ' ':"12470",
	    'START':"NnNn",
	    'STOP':"WnNn",
	};

	var c = makeCode(code);
	code = c[0];
	var bits = c[1];

	var g = new Graphics(width, height, this.border, this.padding
		, this.font, this.fontsize);

	//get the width of a narrow bar dynamically 
	//depending on the size of the code
	//and the available width
	var narrow_width = getnarrow(code, g.area.width);
	var wide_width = narrow_width * MULTIPLE;
	
	var x=g.area.left;
	for(var bit =0, len = bits.length; bit<len; bit++){
		var chr = bits[bit];
		var chr_l = chr.toLowerCase();
		var x2 =0; //the far x
		var current_width = wide_width;
		if(chr_l == 'n'){
			x2 = x+narrow_width;
			current_width = narrow_width;
		}
		x2 = x+current_width;
		if(chr =='N' || chr == 'W'){
			//if bar and not space
			g.fillFgRect(Math.round(x), 0, current_width, height);
		}
		x = x2;
	}
	

	if(this.hri==true){
		//** and print the hri
		g.fillText(code, width/2, height);
	}

    if(angle>0){
    	g.rotate(angle);
	}
	

	
	var buf = g.toBuffer();
	if(useCallback){
		//called with callback
		callback(null, buf, code, bits);
		return buf;
	}
	else{
		//regular return
		return buf;
	}

	function makeCode(code){
		if((code.length % 2) != 0){
			//the length of an 2of5 code must be even
			code = "0" +code;
	 	}
	 	var strCode = VALUE_ENCODINGS['START'];
	 	var bar = true
	 	var values = [];
	 	for(var i = 0, len=code.length; i<len;i++){
	 		var encoding = VALUE_ENCODINGS[code[i]];
	 		if (bar){
	 			encoding = encoding.toUpperCase();
	 		}
	 		else {
	 			encoding = encoding.toLowerCase();
	 		}
	 		values.push(encoding);
	 		bar = !bar;
	 		if(values.length == 2){
	 			for(var j=0; j<5;j++){
	 				strCode += values[0][j] + values[1][j];
	 			}
	 			values = [];
	 			bar=true;
	 		}
	 	}
	 	strCode += VALUE_ENCODINGS['STOP'];
	 	return [code, strCode];
	}

	function getnarrow(code, width){
	        //returns narrow width in pixels
	        /*
	        L = (C (2N + 3) + 6 + N)X
	        L = length of symbol (not counting quiet zone)
	        C = number of code characters
	        X = X-dimension
	        N = wide-to-narrow MULTIPLE
	        */
	        narrow = code.length * (2.0*MULTIPLE+3.0)+6.0+MULTIPLE
	        return width/narrow
	}
}
